@@ -13,26 +13,28 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 6485 $
-## |  Last changed: $Date: 2022-08-12 13:20:22 +0200 (Fr, 12 Aug 2022) $
+## |  File version: $Revision: 7742 $
+## |  Last changed: $Date: 2024-03-22 13:46:29 +0100 (Fr, 22 Mrz 2024) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
 #' @include f_logger.R
 NULL
 
-# @title
-# Get Analysis Results Rates
-#
-# @description
-# Returns an analysis result object.
-#
-# @param design The trial design.
-#
-# @return Returns a \code{AnalysisResultsRates} object.
-#
-# @keywords internal
-#
+#' @title
+#' Get Analysis Results Rates
+#'
+#' @description
+#' Returns an analysis result object.
+#'
+#' @param design The trial design.
+#'
+#' @return Returns a \code{AnalysisResultsRates} object.
+#'
+#' @keywords internal
+#'
+#' @noRd
+#'
 .getAnalysisResultsRates <- function(..., design, dataInput) {
     if (.isTrialDesignGroupSequential(design)) {
         return(.getAnalysisResultsRatesGroupSequential(
@@ -55,7 +57,7 @@ NULL
         ))
     }
 
-    .stopWithWrongDesignMessage(design)
+    .stopWithWrongDesignMessage(design, inclusiveConditionalDunnett = FALSE)
 }
 
 .getAnalysisResultsRatesInverseNormal <- function(..., design,
@@ -74,7 +76,7 @@ NULL
         ), "stage"), ...
     )
 
-    results <- AnalysisResultsInverseNormal(design = design, dataInput = dataInput)
+    results <- AnalysisResultsInverseNormal$new(design = design, dataInput = dataInput) # R6$new
 
     .getAnalysisResultsRatesAll(
         results = results, design = design, dataInput = dataInput,
@@ -103,7 +105,7 @@ NULL
         ), "stage"), ...
     )
 
-    results <- AnalysisResultsGroupSequential(design = design, dataInput = dataInput)
+    results <- AnalysisResultsGroupSequential$new(design = design, dataInput = dataInput) # R6$new
 
     .getAnalysisResultsRatesAll(
         results = results, design = design, dataInput = dataInput,
@@ -134,7 +136,7 @@ NULL
         ), "stage"), ...
     )
 
-    results <- AnalysisResultsFisher(design = design, dataInput = dataInput)
+    results <- AnalysisResultsFisher$new(design = design, dataInput = dataInput) # R6$new
     .setValueAndParameterType(results, "iterations", as.integer(iterations), C_ITERATIONS_DEFAULT)
     .setValueAndParameterType(results, "seed", seed, NA_real_)
 
@@ -150,10 +152,12 @@ NULL
     return(results)
 }
 
-#
-# The following parameters will be taken from 'design':
-# stages, informationRates, criticalValues, futilityBounds, alphaSpent, stageLevels
-#
+#'
+#' The following parameters will be taken from 'design':
+#' stages, informationRates, criticalValues, futilityBounds, alphaSpent, stageLevels
+#'
+#' @noRd
+#'
 .getAnalysisResultsRatesAll <- function(..., results, design, dataInput, stage,
         directionUpper, normalApproximation, thetaH0, pi1, pi2,
         nPlanned, allocationRatioPlanned, tolerance,
@@ -214,7 +218,6 @@ NULL
     results$.setParameterType("testActions", C_PARAM_GENERATED)
 
     if (design$kMax > 1) {
-
         # conditional power
         startTime <- Sys.time()
         if (.isTrialDesignFisher(design)) {
@@ -278,10 +281,9 @@ NULL
     .logProgress("Repeated p-values calculated", startTime = startTime)
 
     if (design$kMax > 1) {
-
         # final p-value
         startTime <- Sys.time()
-        finalPValue <- getFinalPValue(stageResults)
+        finalPValue <- getFinalPValue(stageResults, showWarnings = FALSE)
         results$finalPValues <- .getVectorWithFinalValueAtFinalStage(
             kMax = design$kMax,
             finalValue = finalPValue$pFinal, finalStage = finalPValue$finalStage
@@ -323,25 +325,27 @@ NULL
     return(results)
 }
 
-# @title
-# Get Stage Results Rates
-#
-# @description
-# Returns a stage results object.
-#
-# @param design the trial design.
-#
-# @return Returns a \code{StageResultsRates} object.
-#
-# @keywords internal
-#
+#' @title
+#' Get Stage Results Rates
+#'
+#' @description
+#' Returns a stage results object.
+#'
+#' @param design the trial design.
+#'
+#' @return Returns a \code{StageResultsRates} object.
+#'
+#' @keywords internal
+#'
+#' @noRd
+#'
 .getStageResultsRates <- function(..., design, dataInput, thetaH0 = NA_real_,
         directionUpper = C_DIRECTION_UPPER_DEFAULT,
         normalApproximation = C_NORMAL_APPROXIMATION_RATES_DEFAULT,
         stage = NA_integer_, userFunctionCallEnabled = FALSE) {
     .assertIsDatasetRates(dataInput)
     .assertIsValidThetaH0DataInput(thetaH0, dataInput)
-    directionUpper <- .assertIsValidDirectionUpper(directionUpper, design$sided,
+    .assertIsValidDirectionUpper(directionUpper, design$sided,
         userFunctionCallEnabled = userFunctionCallEnabled
     )
     .assertIsSingleLogical(normalApproximation, "normalApproximation")
@@ -566,7 +570,7 @@ NULL
 
     direction <- ifelse(directionUpper, C_DIRECTION_UPPER, C_DIRECTION_LOWER)
 
-    stageResults <- StageResultsRates(
+    stageResults <- StageResultsRates$new( # R6$new
         design = design,
         dataInput = dataInput,
         stage = as.integer(stage),
@@ -613,9 +617,11 @@ NULL
     return(stageResults)
 }
 
-#
-#  Calculation of lower and upper limits of repeated confidence intervals (RCIs) for Rates
-#
+#'
+#' Calculation of lower and upper limits of repeated confidence intervals (RCIs) for Rates
+#'
+#' @noRd
+#'
 .getRepeatedConfidenceIntervalsRates <- function(..., design) {
     if (.isTrialDesignGroupSequential(design)) {
         return(.getRepeatedConfidenceIntervalsRatesGroupSequential(design = design, ...))
@@ -629,7 +635,7 @@ NULL
         return(.getRepeatedConfidenceIntervalsRatesFisher(design = design, ...))
     }
 
-    .stopWithWrongDesignMessage(design)
+    .stopWithWrongDesignMessage(design, inclusiveConditionalDunnett = FALSE)
 }
 
 .getRootThetaRates <- function(..., design, dataInput, stage, directionUpper, normalApproximation,
@@ -695,84 +701,85 @@ NULL
     repeatedConfidenceIntervals <- matrix(NA_real_, 2, design$kMax)
     for (k in (1:stage)) {
         startTime <- Sys.time()
-		if (criticalValues[k] < C_QNORM_MAXIMUM) {		
-		
-	        # finding upper and lower RCI limits through root function
-	        if (dataInput$getNumberOfGroups() == 1) {
-	            if (dataInput$overallEvents[k] == 0) {
-	                repeatedConfidenceIntervals[1, k] <- 0
-	            } else {
-	                repeatedConfidenceIntervals[1, k] <- .getRootThetaRates(
-	                    design = design, dataInput = dataInput, stage = k,
-	                    directionUpper = C_DIRECTION_UPPER_DEFAULT, normalApproximation = normalApproximation,
-	                    firstParameterName = firstParameterName, secondValue = criticalValues[k], tolerance = tolerance,
-	                    acceptResultsOutOfTolerance = TRUE,
-	                    callingFunctionInformation = paste0("Repeated confidence interval [1, ", k, "]")
-	                )
-	            }
-	
-	            if (dataInput$overallEvents[k] == dataInput$overallSampleSizes[k]) {
-	                repeatedConfidenceIntervals[2, k] <- 1
-	            } else {
-	                repeatedConfidenceIntervals[2, k] <- .getRootThetaRates(
-	                    design = design, dataInput = dataInput, stage = k,
-	                    directionUpper = FALSE, normalApproximation = normalApproximation,
-	                    firstParameterName = firstParameterName, secondValue = criticalValues[k], tolerance = tolerance,
-	                    acceptResultsOutOfTolerance = TRUE,
-	                    callingFunctionInformation = paste0("Repeated confidence interval [2, ", k, "]")
-	                )
-	            }
-	        } else if (dataInput$getNumberOfGroups() == 2) {
-	            repeatedConfidenceIntervals[1, k] <- .getRootThetaRates(
-	                design = design, dataInput = dataInput, stage = k,
-	                directionUpper = C_DIRECTION_UPPER_DEFAULT, normalApproximation = normalApproximation,
-	                firstParameterName = firstParameterName, secondValue = criticalValues[k], tolerance = tolerance,
-	                acceptResultsOutOfTolerance = TRUE,
-	                callingFunctionInformation = paste0("Repeated confidence interval [1, ", k, "]")
-	            )
-	
-	            repeatedConfidenceIntervals[2, k] <- .getRootThetaRates(
-	                design = design, dataInput = dataInput, stage = k,
-	                directionUpper = FALSE, normalApproximation = normalApproximation,
-	                firstParameterName = firstParameterName, secondValue = criticalValues[k], tolerance = tolerance,
-	                acceptResultsOutOfTolerance = TRUE,
-	                callingFunctionInformation = paste0("Repeated confidence interval [1, ", k, "]")
-	            )
-	        }
-			
-	        # adjustment for binding futility bounds
-			if (k > 1 && !is.na(bounds[k - 1]) && conditionFunction(bounds[k - 1], border) && design$bindingFutility) {
-	            parameterName <- ifelse(.isTrialDesignFisher(design), "pValues", firstParameterName)
-	
-	            futilityCorr[k] <- .getRootThetaRates(
-	                design = design, dataInput = dataInput, stage = k - 1,
-	                directionUpper = directionUpper, normalApproximation = normalApproximation,
-	                firstParameterName = parameterName, secondValue = bounds[k - 1], tolerance = tolerance,
-	                acceptResultsOutOfTolerance = TRUE,
-	                callingFunctionInformation = paste0("Repeated confidence interval, futility correction [", k, "]")
-	            )
-	
-	            if (directionUpper) {
-	                repeatedConfidenceIntervals[1, k] <- min(min(futilityCorr[2:k]), repeatedConfidenceIntervals[1, k])
-	            } else {
-	                repeatedConfidenceIntervals[2, k] <- max(max(futilityCorr[2:k]), repeatedConfidenceIntervals[2, k])
-	            }
-	        }
-	        .logProgress("Repeated confidence interval of stage %s calculated", startTime = startTime, k)
-	    }
-	
-	    if (!is.na(repeatedConfidenceIntervals[1, k]) && !is.na(repeatedConfidenceIntervals[2, k]) &&
-	            repeatedConfidenceIntervals[1, k] > repeatedConfidenceIntervals[2, k]) {
-	        repeatedConfidenceIntervals[, k] <- rep(NA_real_, 2)
-	    }
-	}	
+        if (criticalValues[k] < C_QNORM_MAXIMUM) {
+            # finding upper and lower RCI limits through root function
+            if (dataInput$getNumberOfGroups() == 1) {
+                if (dataInput$overallEvents[k] == 0) {
+                    repeatedConfidenceIntervals[1, k] <- 0
+                } else {
+                    repeatedConfidenceIntervals[1, k] <- .getRootThetaRates(
+                        design = design, dataInput = dataInput, stage = k,
+                        directionUpper = C_DIRECTION_UPPER_DEFAULT, normalApproximation = normalApproximation,
+                        firstParameterName = firstParameterName, secondValue = criticalValues[k], tolerance = tolerance,
+                        acceptResultsOutOfTolerance = TRUE,
+                        callingFunctionInformation = paste0("Repeated confidence interval [1, ", k, "]")
+                    )
+                }
+
+                if (dataInput$overallEvents[k] == dataInput$overallSampleSizes[k]) {
+                    repeatedConfidenceIntervals[2, k] <- 1
+                } else {
+                    repeatedConfidenceIntervals[2, k] <- .getRootThetaRates(
+                        design = design, dataInput = dataInput, stage = k,
+                        directionUpper = FALSE, normalApproximation = normalApproximation,
+                        firstParameterName = firstParameterName, secondValue = criticalValues[k], tolerance = tolerance,
+                        acceptResultsOutOfTolerance = TRUE,
+                        callingFunctionInformation = paste0("Repeated confidence interval [2, ", k, "]")
+                    )
+                }
+            } else if (dataInput$getNumberOfGroups() == 2) {
+                repeatedConfidenceIntervals[1, k] <- .getRootThetaRates(
+                    design = design, dataInput = dataInput, stage = k,
+                    directionUpper = C_DIRECTION_UPPER_DEFAULT, normalApproximation = normalApproximation,
+                    firstParameterName = firstParameterName, secondValue = criticalValues[k], tolerance = tolerance,
+                    acceptResultsOutOfTolerance = TRUE,
+                    callingFunctionInformation = paste0("Repeated confidence interval [1, ", k, "]")
+                )
+
+                repeatedConfidenceIntervals[2, k] <- .getRootThetaRates(
+                    design = design, dataInput = dataInput, stage = k,
+                    directionUpper = FALSE, normalApproximation = normalApproximation,
+                    firstParameterName = firstParameterName, secondValue = criticalValues[k], tolerance = tolerance,
+                    acceptResultsOutOfTolerance = TRUE,
+                    callingFunctionInformation = paste0("Repeated confidence interval [1, ", k, "]")
+                )
+            }
+
+            # adjustment for binding futility bounds
+            if (k > 1 && !is.na(bounds[k - 1]) && conditionFunction(bounds[k - 1], border) && design$bindingFutility) {
+                parameterName <- ifelse(.isTrialDesignFisher(design), "pValues", firstParameterName)
+
+                futilityCorr[k] <- .getRootThetaRates(
+                    design = design, dataInput = dataInput, stage = k - 1,
+                    directionUpper = directionUpper, normalApproximation = normalApproximation,
+                    firstParameterName = parameterName, secondValue = bounds[k - 1], tolerance = tolerance,
+                    acceptResultsOutOfTolerance = TRUE,
+                    callingFunctionInformation = paste0("Repeated confidence interval, futility correction [", k, "]")
+                )
+
+                if (directionUpper) {
+                    repeatedConfidenceIntervals[1, k] <- min(min(futilityCorr[2:k]), repeatedConfidenceIntervals[1, k])
+                } else {
+                    repeatedConfidenceIntervals[2, k] <- max(max(futilityCorr[2:k]), repeatedConfidenceIntervals[2, k])
+                }
+            }
+            .logProgress("Repeated confidence interval of stage %s calculated", startTime = startTime, k)
+        }
+
+        if (!is.na(repeatedConfidenceIntervals[1, k]) && !is.na(repeatedConfidenceIntervals[2, k]) &&
+                repeatedConfidenceIntervals[1, k] > repeatedConfidenceIntervals[2, k]) {
+            repeatedConfidenceIntervals[, k] <- rep(NA_real_, 2)
+        }
+    }
 
     return(repeatedConfidenceIntervals)
 }
 
-#
-# RCIs based on group sequential method
-#
+#'
+#' RCIs based on group sequential method
+#'
+#' @noRd
+#'
 .getRepeatedConfidenceIntervalsRatesGroupSequential <- function(...,
         design, dataInput,
         normalApproximation = C_NORMAL_APPROXIMATION_RATES_DEFAULT,
@@ -794,9 +801,11 @@ NULL
     ))
 }
 
-#
-# RCIs based on inverse normal combination test
-#
+#'
+#' RCIs based on inverse normal combination test
+#'
+#' @noRd
+#'
 .getRepeatedConfidenceIntervalsRatesInverseNormal <- function(...,
         design, dataInput,
         normalApproximation = C_NORMAL_APPROXIMATION_RATES_DEFAULT,
@@ -818,9 +827,11 @@ NULL
     ))
 }
 
-#
-# RCIs based on Fisher's combination test
-#
+#'
+#' RCIs based on Fisher's combination test
+#'
+#' @noRd
+#'
 .getRepeatedConfidenceIntervalsRatesFisher <- function(...,
         design, dataInput,
         normalApproximation = C_NORMAL_APPROXIMATION_RATES_DEFAULT,
@@ -843,7 +854,6 @@ NULL
 }
 
 .calculateThetaH1 <- function(stageResults, pi1, pi2, stage, kMax, nPlanned, allocationRatioPlanned) {
-
     # Shifted decision region for use in getGroupSequentialProbabilities
     # Inverse normal method
     condError <- getConditionalRejectionProbabilities(stageResults = stageResults)[stage]
@@ -897,9 +907,11 @@ NULL
     return(list(thetaH1 = thetaH1, nPlanned = nPlanned))
 }
 
-#
-# Calculation of conditional power based on group sequential / inverse normal method
-#
+#'
+#' Calculation of conditional power based on group sequential / inverse normal method
+#'
+#' @noRd
+#'
 .getConditionalPowerRatesInverseNormalOrGroupSequential <- function(..., stageResults, stage = stageResults$stage,
         nPlanned, allocationRatioPlanned = C_ALLOCATION_RATIO_DEFAULT, pi1, pi2) {
     design <- stageResults$.design
@@ -994,9 +1006,11 @@ NULL
     ))
 }
 
-#
-# Calculation of conditional power based on Fisher combination test
-#
+#'
+#' Calculation of conditional power based on Fisher combination test
+#'
+#' @noRd
+#'
 .getConditionalPowerRatesFisher <- function(..., stageResults, stage = stageResults$stage,
         nPlanned, allocationRatioPlanned = C_ALLOCATION_RATIO_DEFAULT,
         pi1, pi2, iterations = C_ITERATIONS_DEFAULT, seed = NA_real_) {
@@ -1088,7 +1102,7 @@ NULL
         pi2 <- .assertIsValidPi2(pi2, stageResults, stage)
     }
 
-    results <- ConditionalPowerResultsRates(
+    results <- ConditionalPowerResultsRates$new( # R6$new
         .stageResults = stageResults,
         .design = stageResults$.design, nPlanned = nPlanned,
         allocationRatioPlanned = allocationRatioPlanned, pi1 = pi1, pi2 = pi2
@@ -1117,7 +1131,7 @@ NULL
         results$simulated <- cp$simulated
         .updateParameterTypeOfIterationsAndSeed(results, ...)
     } else {
-        .stopWithWrongDesignMessage(stageResults$.design)
+        .stopWithWrongDesignMessage(stageResults$.design, inclusiveConditionalDunnett = FALSE)
     }
 
     results$nPlanned <- cp$nPlanned
@@ -1259,10 +1273,12 @@ NULL
     ))
 }
 
-#
-# Calculation of final confidence interval
-# based on group sequential test without SSR (general case).
-#
+#'
+#' Calculation of final confidence interval
+#' based on group sequential test without SSR (general case).
+#'
+#' @noRd
+#'
 .getFinalConfidenceIntervalRatesGroupSequential <- function(..., design, dataInput, stage,
         thetaH0 = C_THETA_H0_RATES_DEFAULT, directionUpper = C_DIRECTION_UPPER_DEFAULT,
         normalApproximation = C_NORMAL_APPROXIMATION_RATES_DEFAULT,
@@ -1401,8 +1417,13 @@ NULL
         }
     }
 
-    finalConfidenceIntervalGeneral <- sort(finalConfidenceIntervalGeneral)
-    finalConfidenceInterval <- sort(finalConfidenceInterval)
+    if (!any(is.na(finalConfidenceIntervalGeneral))) {
+        finalConfidenceIntervalGeneral <- sort(finalConfidenceIntervalGeneral)
+    }
+    if (!any(is.na(finalConfidenceInterval))) {
+        finalConfidenceInterval <- sort(finalConfidenceInterval)
+    }
+
     if (dataInput$getNumberOfGroups() == 1) {
         finalConfidenceInterval[1] <- max(0, finalConfidenceInterval[1])
         finalConfidenceInterval[2] <- min(1, finalConfidenceInterval[2])
@@ -1413,10 +1434,10 @@ NULL
 
     return(list(
         stage = stage,
-        thetaH0 = thetaH0, 
+        thetaH0 = thetaH0,
         directionUpper = directionUpper,
         normalApproximation = normalApproximation,
-        tolerance = tolerance,            
+        tolerance = tolerance,
         finalStage = finalStage,
         medianUnbiasedGeneral = medianUnbiasedGeneral,
         finalConfidenceIntervalGeneral = finalConfidenceIntervalGeneral,
@@ -1425,10 +1446,12 @@ NULL
     ))
 }
 
-#
-# Calculation of final confidence interval
-# based on inverse normal method, only valid for kMax <= 2 or no SSR.
-#
+#'
+#' Calculation of final confidence interval
+#' based on inverse normal method, only valid for kMax <= 2 or no SSR.
+#'
+#' @noRd
+#'
 .getFinalConfidenceIntervalRatesInverseNormal <- function(..., design, dataInput, stage,
         thetaH0 = C_THETA_H0_RATES_DEFAULT, directionUpper = C_DIRECTION_UPPER_DEFAULT,
         normalApproximation = C_NORMAL_APPROXIMATION_RATES_DEFAULT,
@@ -1591,10 +1614,10 @@ NULL
 
     return(list(
         stage = stage,
-        thetaH0 = thetaH0, 
+        thetaH0 = thetaH0,
         directionUpper = directionUpper,
         normalApproximation = normalApproximation,
-        tolerance = tolerance,            
+        tolerance = tolerance,
         finalStage = finalStage,
         medianUnbiasedGeneral = medianUnbiasedGeneral,
         finalConfidenceIntervalGeneral = finalConfidenceIntervalGeneral,
@@ -1603,10 +1626,12 @@ NULL
     ))
 }
 
-#
-# Calculation of final confidence interval
-# based on Fisher combination test, only valid for kMax <= 2.
-#
+#'
+#' Calculation of final confidence interval
+#' based on Fisher combination test, only valid for kMax <= 2.
+#'
+#' @noRd
+#'
 .getFinalConfidenceIntervalRatesFisher <- function(..., design, dataInput, stage,
         thetaH0 = C_THETA_H0_RATES_DEFAULT, directionUpper = C_DIRECTION_UPPER_DEFAULT,
         normalApproximation = C_NORMAL_APPROXIMATION_RATES_DEFAULT,
@@ -1637,10 +1662,10 @@ NULL
 
     return(list(
         stage = stage,
-        thetaH0 = thetaH0, 
+        thetaH0 = thetaH0,
         directionUpper = directionUpper,
         normalApproximation = normalApproximation,
-        tolerance = tolerance,            
+        tolerance = tolerance,
         finalStage = finalStage,
         medianUnbiased = medianUnbiased,
         finalConfidenceInterval = finalConfidenceInterval
@@ -1696,5 +1721,5 @@ NULL
         ))
     }
 
-    .stopWithWrongDesignMessage(design)
+    .stopWithWrongDesignMessage(design, inclusiveConditionalDunnett = FALSE)
 }
