@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 6485 $
-## |  Last changed: $Date: 2022-08-12 13:20:22 +0200 (Fr, 12 Aug 2022) $
+## |  File version: $Revision: 7742 $
+## |  Last changed: $Date: 2024-03-22 13:46:29 +0100 (Fr, 22 Mrz 2024) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -165,7 +165,6 @@ NULL
     ))
 }
 
-
 .getStageResultsRatesEnrichment <- function(..., design, dataInput,
         thetaH0 = C_THETA_H0_RATES_DEFAULT,
         directionUpper = C_DIRECTION_UPPER_DEFAULT,
@@ -235,7 +234,7 @@ NULL
         )
     }
 
-    stageResults <- StageResultsEnrichmentRates(
+    stageResults <- StageResultsEnrichmentRates$new(
         design = design,
         dataInput = dataInput,
         thetaH0 = thetaH0,
@@ -369,7 +368,7 @@ NULL
         return(.getAnalysisResultsRatesFisherEnrichment(design = design, dataInput = dataInput, ...))
     }
 
-    .stopWithWrongDesignMessage(design)
+    .stopWithWrongDesignMessageEnrichment(design)
 }
 
 .getAnalysisResultsRatesInverseNormalEnrichment <- function(...,
@@ -392,7 +391,7 @@ NULL
         ), "stage"), ...
     )
 
-    results <- AnalysisResultsEnrichmentInverseNormal(design = design, dataInput = dataInput)
+    results <- AnalysisResultsEnrichmentInverseNormal$new(design = design, dataInput = dataInput)
 
     results <- .getAnalysisResultsRatesEnrichmentAll(
         results = results, design = design, dataInput = dataInput,
@@ -429,10 +428,10 @@ NULL
         ), "stage"), ...
     )
 
-    results <- AnalysisResultsEnrichmentFisher(design = design, dataInput = dataInput)
+    results <- AnalysisResultsEnrichmentFisher$new(design = design, dataInput = dataInput)
     .setValueAndParameterType(results, "iterations", as.integer(iterations), C_ITERATIONS_DEFAULT)
     .setValueAndParameterType(results, "seed", seed, NA_real_)
-    
+
     results <- .getAnalysisResultsRatesEnrichmentAll(
         results = results, design = design, dataInput = dataInput,
         intersectionTest = intersectionTest, stage = stage, directionUpper = directionUpper,
@@ -507,7 +506,6 @@ NULL
     .logProgress("Closed test calculated", startTime = startTime)
 
     if (design$kMax > 1) {
-
         # conditional power
         startTime <- Sys.time()
         if (.isTrialDesignFisher(design)) {
@@ -593,7 +591,6 @@ NULL
     return(result)
 }
 
-
 .getRepeatedConfidenceIntervalsRatesEnrichmentAll <- function(...,
         design, dataInput,
         directionUpper = C_DIRECTION_UPPER_DEFAULT,
@@ -638,7 +635,7 @@ NULL
     for (k in stages) {
         startTime <- Sys.time()
         for (population in 1:gMax) {
-			if (!is.na(stageResults$testStatistics[population, k]) && criticalValues[k] < C_QNORM_MAXIMUM) {
+            if (!is.na(stageResults$testStatistics[population, k]) && criticalValues[k] < C_QNORM_MAXIMUM) {
                 thetaLow <- -1 + tolerance
                 thetaUp <- 1 - tolerance
                 # finding upper and lower RCI limits through root function
@@ -663,7 +660,7 @@ NULL
                 )
 
                 # adjustment for binding futility bounds
-				if (k > 1 && !is.na(bounds[k - 1]) && conditionFunction(bounds[k - 1], border) && design$bindingFutility) {
+                if (k > 1 && !is.na(bounds[k - 1]) && conditionFunction(bounds[k - 1], border) && design$bindingFutility) {
                     parameterName <- ifelse(.isTrialDesignFisher(design),
                         "singleStepAdjustedPValues", firstParameterName
                     )
@@ -704,9 +701,11 @@ NULL
     return(repeatedConfidenceIntervals)
 }
 
-#
-# RCIs based on inverse normal combination test
-#
+#'
+#' RCIs based on inverse normal combination test
+#'
+#' @noRd
+#'
 .getRepeatedConfidenceIntervalsRatesEnrichmentInverseNormal <- function(...,
         design, dataInput,
         normalApproximation = C_NORMAL_APPROXIMATION_RATES_DEFAULT,
@@ -736,9 +735,11 @@ NULL
     ))
 }
 
-#
-# RCIs based on Fisher's combination test
-#
+#'
+#' RCIs based on Fisher's combination test
+#'
+#' @noRd
+#'
 .getRepeatedConfidenceIntervalsRatesEnrichmentFisher <- function(...,
         design, dataInput,
         normalApproximation = C_NORMAL_APPROXIMATION_RATES_DEFAULT,
@@ -768,22 +769,28 @@ NULL
     ))
 }
 
-#
-#  Calculation of repeated confidence intervals (RCIs) for Rates
-#
+#'
+#' Calculation of repeated confidence intervals (RCIs) for Rates
+#'
+#' @noRd
+#'
 .getRepeatedConfidenceIntervalsRatesEnrichment <- function(..., design) {
     if (.isTrialDesignInverseNormal(design)) {
         return(.getRepeatedConfidenceIntervalsRatesEnrichmentInverseNormal(design = design, ...))
     }
+
     if (.isTrialDesignFisher(design)) {
         return(.getRepeatedConfidenceIntervalsRatesEnrichmentFisher(design = design, ...))
     }
-    .stopWithWrongDesignMessage(design)
+
+    .stopWithWrongDesignMessageEnrichment(design)
 }
 
-#
-#  Calculation of conditional power for Rates
-#
+#'
+#' Calculation of conditional power for Rates
+#'
+#' @noRd
+#'
 .getConditionalPowerRatesEnrichment <- function(..., stageResults, stage = stageResults$stage,
         nPlanned, allocationRatioPlanned = C_ALLOCATION_RATIO_DEFAULT,
         piTreatments = NA_real_, piControls = NA_real_, useAdjustment = TRUE,
@@ -818,7 +825,7 @@ NULL
         piControl <- piControlH1
     }
 
-    results <- ConditionalPowerResultsEnrichmentRates(
+    results <- ConditionalPowerResultsEnrichmentRates$new(
         .design = design,
         .stageResults = stageResults,
         piControls = piControls,
@@ -892,7 +899,7 @@ NULL
             useAdjustment = useAdjustment,
             piControls = piControls,
             piTreatments = piTreatments,
-            iterations = iterations, 
+            iterations = iterations,
             seed = seed, ...
         ))
     }
@@ -903,9 +910,11 @@ NULL
     )
 }
 
-#
-# Calculation of conditional power based on inverse normal method
-#
+#'
+#' Calculation of conditional power based on inverse normal method
+#'
+#' @noRd
+#'
 .getConditionalPowerRatesEnrichmentInverseNormal <- function(..., results, design, stageResults, stage,
         allocationRatioPlanned, nPlanned, piTreatments, piControls) {
     .assertIsTrialDesignInverseNormal(design)
@@ -1006,13 +1015,14 @@ NULL
     return(results)
 }
 
-#
-# Calculation of conditional power based on Fisher's combination test
-#
+#'
+#' Calculation of conditional power based on Fisher's combination test
+#'
+#' @noRd
+#'
 .getConditionalPowerRatesEnrichmentFisher <- function(..., results, design, stageResults, stage,
         allocationRatioPlanned, nPlanned, piTreatments, piControls, useAdjustment = TRUE,
         iterations, seed) {
-        
     .assertIsTrialDesignFisher(design)
     .assertIsValidIterationsAndSeed(iterations, seed, zeroIterationsAllowed = FALSE)
     .warnInCaseOfUnknownArguments(
@@ -1121,9 +1131,11 @@ NULL
     return(results)
 }
 
-#
-# Calculation of conditional power and likelihood values for plotting the graph
-#
+#'
+#' Calculation of conditional power and likelihood values for plotting the graph
+#'
+#' @noRd
+#'
 .getConditionalPowerLikelihoodRatesEnrichment <- function(..., stageResults, stage,
         nPlanned, allocationRatioPlanned = C_ALLOCATION_RATIO_DEFAULT,
         piTreatmentRange, piControls = NA_real_,
@@ -1153,7 +1165,7 @@ NULL
     stdErr <- sqrt(stageResults$overallPisTreatment[, stage] * (1 - stageResults$overallPisTreatment[, stage])) /
         sqrt(stageResults$.overallSampleSizes2[, stage])
 
-    results <- ConditionalPowerResultsEnrichmentRates(
+    results <- ConditionalPowerResultsEnrichmentRates$new(
         .design = design,
         .stageResults = stageResults,
         piControls = piControls,
