@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 6619 $
-## |  Last changed: $Date: 2022-10-20 11:41:21 +0200 (Thu, 20 Oct 2022) $
+## |  File version: $Revision: 7742 $
+## |  Last changed: $Date: 2024-03-22 13:46:29 +0100 (Fr, 22 Mrz 2024) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 ## |
@@ -22,18 +22,21 @@
 #' @include f_logger.R
 NULL
 
-# @title
-# Get Analysis Results Survival
-#
-# @description
-# Returns an analysis result object.
-#
-# @param design The trial design.
-#
-# @return Returns a \code{AnalysisResultsSurvival} object.
-#
-# @keywords internal
-#
+#'
+#' @title
+#' Get Analysis Results Survival
+#'
+#' @description
+#' Returns an analysis result object.
+#'
+#' @param design The trial design.
+#'
+#' @return Returns a \code{AnalysisResultsSurvival} object.
+#'
+#' @keywords internal
+#'
+#' @noRd
+#'
 .calcSurvivalTestStatistics <- function(dataInput, subset, stage, thetaH0,
         stratifiedAnalysis, directionUpper = TRUE) {
     overallEvents <- NA_real_
@@ -170,7 +173,7 @@ NULL
         )
     }
 
-    stageResults <- StageResultsEnrichmentSurvival(
+    stageResults <- StageResultsEnrichmentSurvival$new(
         design = design,
         dataInput = dataInput,
         intersectionTest = intersectionTest,
@@ -332,7 +335,7 @@ NULL
         ), "stage"), ...
     )
 
-    results <- AnalysisResultsEnrichmentInverseNormal(design = design, dataInput = dataInput)
+    results <- AnalysisResultsEnrichmentInverseNormal$new(design = design, dataInput = dataInput)
 
     results <- .getAnalysisResultsSurvivalEnrichmentAll(
         results = results, design = design, dataInput = dataInput,
@@ -370,10 +373,10 @@ NULL
         ), "stage"), ...
     )
 
-    results <- AnalysisResultsEnrichmentFisher(design = design, dataInput = dataInput)
+    results <- AnalysisResultsEnrichmentFisher$new(design = design, dataInput = dataInput)
     .setValueAndParameterType(results, "iterations", as.integer(iterations), C_ITERATIONS_DEFAULT)
     .setValueAndParameterType(results, "seed", seed, NA_real_)
-    
+
     results <- .getAnalysisResultsSurvivalEnrichmentAll(
         results = results, design = design, dataInput = dataInput,
         intersectionTest = intersectionTest, stage = stage, directionUpper = directionUpper,
@@ -419,7 +422,6 @@ NULL
     .logProgress("Closed test calculated", startTime = startTime)
 
     if (design$kMax > 1) {
-
         # conditional power
         startTime <- Sys.time()
         if (.isTrialDesignFisher(design)) {
@@ -604,8 +606,7 @@ NULL
     for (k in stages) {
         startTime <- Sys.time()
         for (population in 1:gMax) {
-			if (!is.na(stageResults$testStatistics[population, k]) && criticalValues[k] < C_QNORM_MAXIMUM) {
-				
+            if (!is.na(stageResults$testStatistics[population, k]) && criticalValues[k] < C_QNORM_MAXIMUM) {
                 # Finding maximum upper and minimum lower bounds for RCIs
                 thetaLow <- exp(.getUpperLowerThetaSurvivalEnrichment(
                     design = design, dataInput = dataInput,
@@ -641,7 +642,7 @@ NULL
                 )
 
                 # adjustment for binding futility bounds
-				if (k > 1 && !is.na(bounds[k - 1]) && conditionFunction(bounds[k - 1], border) && design$bindingFutility) {
+                if (k > 1 && !is.na(bounds[k - 1]) && conditionFunction(bounds[k - 1], border) && design$bindingFutility) {
                     parameterName <- ifelse(.isTrialDesignFisher(design),
                         "singleStepAdjustedPValues", firstParameterName
                     )
@@ -694,9 +695,11 @@ NULL
     return(repeatedConfidenceIntervals)
 }
 
-#
-# RCIs based on inverse normal combination test
-#
+#'
+#' RCIs based on inverse normal combination test
+#'
+#' @noRd
+#'
 .getRepeatedConfidenceIntervalsSurvivalEnrichmentInverseNormal <- function(...,
         design, dataInput,
         directionUpper = C_DIRECTION_UPPER_DEFAULT,
@@ -720,9 +723,11 @@ NULL
     ))
 }
 
-#
-# RCIs based on Fisher's combination test
-#
+#'
+#' RCIs based on Fisher's combination test
+#'
+#' @noRd
+#'
 .getRepeatedConfidenceIntervalsSurvivalEnrichmentFisher <- function(...,
         design, dataInput,
         directionUpper = C_DIRECTION_UPPER_DEFAULT,
@@ -746,9 +751,11 @@ NULL
     ))
 }
 
-#
-#  Calculation of lower and upper limits of repeated confidence intervals (RCIs) for Survival
-#
+#'
+#' Calculation of lower and upper limits of repeated confidence intervals (RCIs) for Survival
+#'
+#' @noRd
+#'
 .getRepeatedConfidenceIntervalsSurvivalEnrichment <- function(..., design) {
     if (.isTrialDesignInverseNormal(design)) {
         return(.getRepeatedConfidenceIntervalsSurvivalEnrichmentInverseNormal(design = design, ...))
@@ -761,9 +768,11 @@ NULL
     .stopWithWrongDesignMessageEnrichment(design)
 }
 
-#
-#  Calculation of conditional power for Survival
-#
+#'
+#' Calculation of conditional power for Survival
+#'
+#' @noRd
+#'
 .getConditionalPowerSurvivalEnrichment <- function(..., stageResults, stage = stageResults$stage,
         nPlanned, allocationRatioPlanned = C_ALLOCATION_RATIO_DEFAULT,
         thetaH1 = NA_real_,
@@ -772,7 +781,7 @@ NULL
     gMax <- stageResults$getGMax()
     kMax <- design$kMax
 
-    results <- ConditionalPowerResultsEnrichmentSurvival(
+    results <- ConditionalPowerResultsEnrichmentSurvival$new(
         .design = design,
         .stageResults = stageResults,
         thetaH1 = thetaH1,
@@ -844,9 +853,11 @@ NULL
     )
 }
 
-#
-# Calculation of conditional power based on inverse normal method
-#
+#'
+#' Calculation of conditional power based on inverse normal method
+#'
+#' @noRd
+#'
 .getConditionalPowerSurvivalEnrichmentInverseNormal <- function(..., results, design, stageResults, stage,
         allocationRatioPlanned, nPlanned, thetaH1) {
     .assertIsTrialDesignInverseNormal(design)
@@ -928,9 +939,11 @@ NULL
     return(results)
 }
 
-#
-# Calculation of conditional power based on Fisher's combination test
-#
+#'
+#' Calculation of conditional power based on Fisher's combination test
+#'
+#' @noRd
+#'
 .getConditionalPowerSurvivalEnrichmentFisher <- function(..., results, design, stageResults, stage,
         allocationRatioPlanned, nPlanned, thetaH1, iterations, seed) {
     .assertIsTrialDesignFisher(design)
@@ -1012,9 +1025,11 @@ NULL
     return(results)
 }
 
-#
-# Calculation of conditional power and likelihood values for plotting the graph
-#
+#'
+#' Calculation of conditional power and likelihood values for plotting the graph
+#'
+#' @noRd
+#'
 .getConditionalPowerLikelihoodSurvivalEnrichment <- function(..., stageResults, stage,
         nPlanned, allocationRatioPlanned = C_ALLOCATION_RATIO_DEFAULT,
         thetaRange, iterations = C_ITERATIONS_DEFAULT, seed = NA_real_) {
@@ -1043,7 +1058,7 @@ NULL
 
     stdErr <- 2 / sqrt(stageResults$.overallEvents[, stage])
 
-    results <- ConditionalPowerResultsEnrichmentSurvival(
+    results <- ConditionalPowerResultsEnrichmentSurvival$new(
         .design = design,
         .stageResults = stageResults,
         nPlanned = nPlanned,
