@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 7379 $
-## |  Last changed: $Date: 2023-10-30 16:19:12 +0100 (Mo, 30 Okt 2023) $
+## |  File version: $Revision: 7742 $
+## |  Last changed: $Date: 2024-03-22 13:46:29 +0100 (Fr, 22 Mrz 2024) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -30,8 +30,7 @@ NULL
 #'
 #' @noRd
 #'
-.getAnalysisResultsMultiArm <- function(
-        design, dataInput, ...,
+.getAnalysisResultsMultiArm <- function(design, dataInput, ...,
         intersectionTest = C_INTERSECTION_TEST_MULTIARMED_DEFAULT,
         directionUpper = C_DIRECTION_UPPER_DEFAULT,
         thetaH0 = NA_real_,
@@ -156,8 +155,7 @@ NULL
 #'
 #' @noRd
 #'
-.getConditionalPowerMultiArm <- function(
-        ..., stageResults, nPlanned,
+.getConditionalPowerMultiArm <- function(..., stageResults, nPlanned,
         allocationRatioPlanned = C_ALLOCATION_RATIO_DEFAULT) {
     .assertIsStageResults(stageResults)
 
@@ -212,8 +210,7 @@ NULL
 }
 
 
-.performClosedCombinationTest <- function(
-        ..., stageResults, design = stageResults$.design,
+.performClosedCombinationTest <- function(..., stageResults, design = stageResults$.design,
         intersectionTest = stageResults$intersectionTest) {
     dataInput <- stageResults$.dataInput
     stage <- stageResults$stage
@@ -426,7 +423,7 @@ getClosedCombinationTestResults <- function(stageResults) {
     .assertIsTrialDesignInverseNormalOrFisher(stageResults$.design)
 
     result <- .performClosedCombinationTest(stageResults = stageResults)
-    return(ClosedCombinationTestResults(
+    return(ClosedCombinationTestResults$new(
         .design = result$.design,
         .enrichment = grepl("Enrichment", .getClassName(stageResults)),
         intersectionTest = result$intersectionTest,
@@ -683,7 +680,7 @@ getClosedConditionalDunnettTestResults <- function(stageResults, ..., stage = st
     .assertIsTrialDesignConditionalDunnett(design)
 
     result <- .getClosedConditionalDunnettTestResults(stageResults = stageResults, design = design, stage = stage)
-    return(ClosedCombinationTestResults(
+    return(ClosedCombinationTestResults$new(
         .design = result$.design,
         .enrichment = grepl("Enrichment", .getClassName(stageResults)),
         intersectionTest = result$intersectionTest,
@@ -696,8 +693,7 @@ getClosedConditionalDunnettTestResults <- function(stageResults, ..., stage = st
     ))
 }
 
-.getClosedConditionalDunnettTestResults <- function(
-        ...,
+.getClosedConditionalDunnettTestResults <- function(...,
         stageResults,
         design = stageResults$.design,
         stage = stageResults$stage) {
@@ -758,73 +754,77 @@ getClosedConditionalDunnettTestResults <- function(stageResults, ..., stage = st
     }
 
     for (i in 1:(2^gMax - 1)) {
-        tryCatch({
-        	
-            zeta <- sqrt(frac1[indices[i, ] == 1])
-            sigma <- zeta %*% t(zeta)
-            diag(sigma) <- 1
-            crit <- .getMultivariateDistribution(
-                type = "quantile",
-                upper = NA_real_, sigma = sigma, alpha = alpha
-            )
-    
-            integrandFunction <- function(x) {
-                innerProduct <- 1
-                for (g in (1:gMax)) {
-                    if (indices[i, g] == 1) {
-                        innerProduct <- innerProduct * stats::pnorm(((crit -
-                            sqrt(informationAtInterim) * signedTestStatistics[g, 1] +
-                            sqrt(1 - informationAtInterim) * sqrt(frac1[g]) * x)) /
-                            sqrt((1 - informationAtInterim) * (1 - frac1[g])))
-                    }
-                }
-                return(innerProduct * dnorm(x))
-            }
-            conditionalErrorRate[i, 1] <- 1 - stats::integrate(integrandFunction, lower = -Inf, upper = Inf)$value
-    
-        }, error = function(e) {
-            warning("Failed to calculate conditionalErrorRate[", i, ", 1]: ", e$message)
-        })
-    
-        tryCatch({
-            if (stage == 2) {
-                if (!all(is.na(stageResults$separatePValues[indices[i, ] == 1, 2]))) {
-                    if (secondStageConditioning) {
-                        maxOverallTestStatistic <- max(
-                            signedOverallTestStatistics[indices[i, ] == 1, 2],
-                            na.rm = TRUE
-                        )
-                        integrandFunctionStage2 <- function(x) {
-                            innerProduct <- 1
-                            for (g in (1:gMax)) {
-                                if ((indices[i, g] == 1) && !is.na(stageResults$overallTestStatistics[g, 2])) {
-                                    innerProduct <- innerProduct * stats::pnorm(((maxOverallTestStatistic -
-                                        sqrt(informationAtInterim) * signedTestStatistics[g, 1] +
-                                        sqrt(1 - informationAtInterim) * sqrt(frac2[g]) * x)) /
-                                        sqrt((1 - informationAtInterim) * (1 - frac2[g])))
-                                }
-                            }
-                            return(innerProduct * dnorm(x))
-                        }
-                    } else {
-                        maxTestStatistic <- max(signedTestStatistics[indices[i, ] == 1, 2], na.rm = TRUE)
-                        integrandFunctionStage2 <- function(x) {
-                            innerProduct <- 1
-                            for (g in (1:gMax)) {
-                                if ((indices[i, g] == 1) && !is.na(stageResults$separatePValues[g, 2])) {
-                                    innerProduct <- innerProduct *
-                                        stats::pnorm(((maxTestStatistic + sqrt(frac2[g]) * x)) / sqrt(1 - frac2[g]))
-                                }
-                            }
-                            return(innerProduct * dnorm(x))
+        tryCatch(
+            {
+                zeta <- sqrt(frac1[indices[i, ] == 1])
+                sigma <- zeta %*% t(zeta)
+                diag(sigma) <- 1
+                crit <- .getMultivariateDistribution(
+                    type = "quantile",
+                    upper = NA_real_, sigma = sigma, alpha = alpha
+                )
+
+                integrandFunction <- function(x) {
+                    innerProduct <- 1
+                    for (g in (1:gMax)) {
+                        if (indices[i, g] == 1) {
+                            innerProduct <- innerProduct * stats::pnorm(((crit -
+                                sqrt(informationAtInterim) * signedTestStatistics[g, 1] +
+                                sqrt(1 - informationAtInterim) * sqrt(frac1[g]) * x)) /
+                                sqrt((1 - informationAtInterim) * (1 - frac1[g])))
                         }
                     }
-                    secondStagePValues[i, 2] <- 1 - stats::integrate(integrandFunctionStage2, lower = -Inf, upper = Inf)$value
+                    return(innerProduct * dnorm(x))
                 }
+                conditionalErrorRate[i, 1] <- 1 - stats::integrate(integrandFunction, lower = -Inf, upper = Inf)$value
+            },
+            error = function(e) {
+                warning("Failed to calculate conditionalErrorRate[", i, ", 1]: ", e$message)
             }
-        }, error = function(e) {
-            warning("Failed to calculate secondStagePValues[", i, ", 2]: ", e$message)
-        })
+        )
+
+        tryCatch(
+            {
+                if (stage == 2) {
+                    if (!all(is.na(stageResults$separatePValues[indices[i, ] == 1, 2]))) {
+                        if (secondStageConditioning) {
+                            maxOverallTestStatistic <- max(
+                                signedOverallTestStatistics[indices[i, ] == 1, 2],
+                                na.rm = TRUE
+                            )
+                            integrandFunctionStage2 <- function(x) {
+                                innerProduct <- 1
+                                for (g in (1:gMax)) {
+                                    if ((indices[i, g] == 1) && !is.na(stageResults$overallTestStatistics[g, 2])) {
+                                        innerProduct <- innerProduct * stats::pnorm(((maxOverallTestStatistic -
+                                            sqrt(informationAtInterim) * signedTestStatistics[g, 1] +
+                                            sqrt(1 - informationAtInterim) * sqrt(frac2[g]) * x)) /
+                                            sqrt((1 - informationAtInterim) * (1 - frac2[g])))
+                                    }
+                                }
+                                return(innerProduct * dnorm(x))
+                            }
+                        } else {
+                            maxTestStatistic <- max(signedTestStatistics[indices[i, ] == 1, 2], na.rm = TRUE)
+                            integrandFunctionStage2 <- function(x) {
+                                innerProduct <- 1
+                                for (g in (1:gMax)) {
+                                    if ((indices[i, g] == 1) && !is.na(stageResults$separatePValues[g, 2])) {
+                                        innerProduct <- innerProduct *
+                                            stats::pnorm(((maxTestStatistic + sqrt(frac2[g]) * x)) / sqrt(1 - frac2[g]))
+                                    }
+                                }
+                                return(innerProduct * dnorm(x))
+                            }
+                        }
+                        secondStagePValues[i, 2] <- 1 - stats::integrate(integrandFunctionStage2, lower = -Inf, upper = Inf)$value
+                    }
+                }
+            },
+            error = function(e) {
+                warning("Failed to calculate secondStagePValues[", i, ", 2]: ", e$message)
+            }
+        )
     }
 
     if (stage == 2) {
@@ -948,8 +948,7 @@ getClosedConditionalDunnettTestResults <- function(stageResults, ..., stage = st
 #'
 #' @noRd
 #'
-.getConditionalRejectionProbabilitiesMultiArm <- function(
-        stageResults, ...,
+.getConditionalRejectionProbabilitiesMultiArm <- function(stageResults, ...,
         stage = stageResults$stage, iterations = C_ITERATIONS_DEFAULT, seed = NA_real_) {
     .assertIsValidStage(stage, stageResults$.design$kMax)
     gMax <- stageResults$getGMax()
@@ -1152,8 +1151,7 @@ getClosedConditionalDunnettTestResults <- function(stageResults, ..., stage = st
 #'
 #' @noRd
 #'
-.getConditionalPowerPlotMultiArm <- function(
-        stageResults, ...,
+.getConditionalPowerPlotMultiArm <- function(stageResults, ...,
         nPlanned, allocationRatioPlanned = C_ALLOCATION_RATIO_DEFAULT,
         thetaRange = NA_real_, assumedStDevs = NA_real_,
         piTreatmentRange = NA_real_, piControl = NA_real_,
