@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 7126 $
-## |  Last changed: $Date: 2023-06-23 14:26:39 +0200 (Fr, 23 Jun 2023) $
+## |  File version: $Revision: 7742 $
+## |  Last changed: $Date: 2024-03-22 13:46:29 +0100 (Fr, 22 Mrz 2024) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -79,7 +79,7 @@ NULL
         ), "stage"), ...
     )
 
-    results <- AnalysisResultsMultiArmInverseNormal(design = design, dataInput = dataInput)
+    results <- AnalysisResultsMultiArmInverseNormal$new(design = design, dataInput = dataInput)
 
     results <- .getAnalysisResultsSurvivalMultiArmAll(
         results = results, design = design, dataInput = dataInput,
@@ -113,7 +113,7 @@ NULL
         ), "stage"), ...
     )
 
-    results <- AnalysisResultsMultiArmFisher(design = design, dataInput = dataInput)
+    results <- AnalysisResultsMultiArmFisher$new(design = design, dataInput = dataInput)
     results <- .getAnalysisResultsSurvivalMultiArmAll(
         results = results, design = design, dataInput = dataInput,
         intersectionTest = intersectionTest, stage = stage, directionUpper = directionUpper,
@@ -134,7 +134,8 @@ NULL
         thetaH1 = NA_real_,
         nPlanned = NA_real_,
         allocationRatioPlanned = C_ALLOCATION_RATIO_DEFAULT,
-        tolerance = C_ANALYSIS_TOLERANCE_DEFAULT) {
+        tolerance = C_ANALYSIS_TOLERANCE_DEFAULT,
+        iterations = C_ITERATIONS_DEFAULT, seed = NA_real_) {
     .assertIsTrialDesignConditionalDunnett(design)
     stage <- .getStageFromOptionalArguments(..., dataInput = dataInput, design = design)
     .warnInCaseOfUnknownArguments(
@@ -145,7 +146,7 @@ NULL
         ), "stage"), ...
     )
 
-    results <- AnalysisResultsConditionalDunnett(design = design, dataInput = dataInput)
+    results <- AnalysisResultsConditionalDunnett$new(design = design, dataInput = dataInput)
 
     results <- .getAnalysisResultsSurvivalMultiArmAll(
         results = results, design = design,
@@ -286,7 +287,7 @@ NULL
     )
     .assertIsValidIntersectionTestMultiArm(design, intersectionTest)
 
-    stageResults <- StageResultsMultiArmSurvival(
+    stageResults <- StageResultsMultiArmSurvival$new(
         design = design,
         dataInput = dataInput,
         intersectionTest = intersectionTest,
@@ -801,7 +802,7 @@ NULL
     gMax <- stageResults$getGMax()
     kMax <- design$kMax
 
-    results <- ConditionalPowerResultsMultiArmSurvival(
+    results <- ConditionalPowerResultsMultiArmSurvival$new(
         .design = design,
         .stageResults = stageResults,
         thetaH1 = thetaH1,
@@ -1144,7 +1145,7 @@ NULL
 
     stdErr <- 2 / sqrt(stageResults$.dataInput$getOverallEvents(stage = stage, group = (1:gMax)))
 
-    results <- ConditionalPowerResultsMultiArmSurvival(
+    results <- ConditionalPowerResultsMultiArmSurvival$new(
         .design = design,
         .stageResults = stageResults,
         nPlanned = nPlanned,
