@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 7461 $
-## |  Last changed: $Date: 2023-12-01 10:24:25 +0100 (Fr, 01 Dez 2023) $
+## |  File version: $Revision: 7742 $
+## |  Last changed: $Date: 2024-03-22 13:46:29 +0100 (Fr, 22 Mrz 2024) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -642,7 +642,7 @@ NULL
         )
     }
 
-    setting <- PiecewiseSurvivalTime(
+    setting <- PiecewiseSurvivalTime$new(
         piecewiseSurvivalTime = piecewiseSurvivalTime,
         lambda2 = piecewiseLambda,
         hazardRatio = 1, kappa = kappa,
