@@ -13,13 +13,12 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 7408 $
-## |  Last changed: $Date: 2023-11-09 10:36:19 +0100 (Do, 09 Nov 2023) $
+## |  File version: $Revision: 7742 $
+## |  Last changed: $Date: 2024-03-22 13:46:29 +0100 (Fr, 22 Mrz 2024) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
-.getSimulationRatesStageSubjects <- function(
-        ...,
+.getSimulationRatesStageSubjects <- function(...,
         stage,
         riskRatio,
         thetaH0,
@@ -258,7 +257,7 @@ getSimulationRates <- function(design = NULL, ...,
         )
     }
 
-    simulationResults <- SimulationResultsRates(design, showStatistics = showStatistics)
+    simulationResults <- SimulationResultsRates$new(design, showStatistics = showStatistics)
 
     conditionalPower <- .ignoreParameterIfNotUsed(
         "conditionalPower",
