@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 7620 $
-## |  Last changed: $Date: 2024-02-09 12:57:37 +0100 (Fr, 09 Feb 2024) $
+## |  File version: $Revision: 7742 $
+## |  Last changed: $Date: 2024-03-22 13:46:29 +0100 (Fr, 22 Mrz 2024) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -58,8 +58,7 @@ NULL
     }
 }
 
-.getSimulationPlotXAxisParameterName <- function(
-        simulationResults,
+.getSimulationPlotXAxisParameterName <- function(simulationResults,
         showSource = FALSE, simulationResultsName = NA_character_) {
     if (grepl("SimulationResultsEnrichment", .getClassName(simulationResults))) {
         effectDataList <- .getSimulationEnrichmentEffectData(simulationResults)
@@ -180,8 +179,7 @@ NULL
     ))
 }
 
-.plotSimulationResults <- function(
-        simulationResults, designMaster, type = 5L, main = NA_character_,
+.plotSimulationResults <- function(simulationResults, designMaster, type = 5L, main = NA_character_,
         xlab = NA_character_, ylab = NA_character_, palette = "Set1",
         theta = seq(-1, 1, 0.02), plotPointsEnabled = NA,
         legendPosition = NA_integer_, showSource = FALSE,
@@ -278,7 +276,7 @@ NULL
     if (type == 1) { # Multi-arm, Overall Success
         .assertIsValidVariedParameterVectorForSimulationResultsPlotting(simulationResults, type)
         if (is.na(main)) {
-            main <- PlotSubTitleItems(title = "Overall Success")
+            main <- PlotSubTitleItems$new(title = "Overall Success")
             .addPlotSubTitleItems(simulationResults, designMaster, main, type)
         }
 
@@ -320,7 +318,7 @@ NULL
     } else if (type == 2) { # Multi-arm, Success per Stage
         .assertIsValidVariedParameterVectorForSimulationResultsPlotting(simulationResults, type)
         if (is.na(main)) {
-            main <- PlotSubTitleItems(title = "Success per Stage")
+            main <- PlotSubTitleItems$new(title = "Success per Stage")
             .addPlotSubTitleItems(simulationResults, designMaster, main, type)
         }
 
@@ -385,7 +383,7 @@ NULL
 
         .assertIsValidVariedParameterVectorForSimulationResultsPlotting(simulationResults, type)
         if (is.na(main)) {
-            main <- PlotSubTitleItems(title = paste0("Selected ", armsCaption, " per Stage"))
+            main <- PlotSubTitleItems$new(title = paste0("Selected ", armsCaption, " per Stage"))
             .addPlotSubTitleItems(simulationResults, designMaster, main, type)
         }
 
@@ -476,7 +474,7 @@ NULL
     } else if (type == 4) { # Multi-arm, Rejected Arms/Populations per Stage
         .assertIsValidVariedParameterVectorForSimulationResultsPlotting(simulationResults, type)
         if (is.na(main)) {
-            main <- PlotSubTitleItems(title = ifelse(!multiArmEnabled,
+            main <- PlotSubTitleItems$new(title = ifelse(!multiArmEnabled,
                 "Reject per Stage",
                 ifelse(designMaster$kMax > 1,
                     paste0("Rejected ", armsCaption, " per Stage"), paste0("Rejected ", armsCaption)
@@ -607,7 +605,7 @@ NULL
         .assertIsValidVariedParameterVectorForSimulationResultsPlotting(simulationResults, type)
 
         if (is.na(main)) {
-            main <- PlotSubTitleItems(title = ifelse(designMaster$kMax == 1,
+            main <- PlotSubTitleItems$new(title = ifelse(designMaster$kMax == 1,
                 "Overall Power", "Overall Power and Early Stopping"
             ))
             .addPlotSubTitleItems(simulationResults, designMaster, main, type)
@@ -694,7 +692,7 @@ NULL
 
         if (is.na(main)) {
             titlePart <- paste0("Expected ", ifelse(survivalEnabled, "Number of Events", "Number of Subjects"))
-            main <- PlotSubTitleItems(title = paste0(
+            main <- PlotSubTitleItems$new(title = paste0(
                 titlePart,
                 ifelse(designMaster$kMax == 1, "", paste0(
                     " and Power",
@@ -727,7 +725,7 @@ NULL
     } else if (type == 7) {
         .assertIsValidVariedParameterVectorForSimulationResultsPlotting(simulationResults, type)
         if (is.na(main)) {
-            main <- PlotSubTitleItems(title = "Overall Power")
+            main <- PlotSubTitleItems$new(title = "Overall Power")
             .addPlotSubTitleItems(simulationResults, designMaster, main, type)
         }
 
@@ -753,7 +751,7 @@ NULL
             !all(na.omit(simulationResults$futilityStop) == 0)
 
         if (is.na(main)) {
-            main <- PlotSubTitleItems(title = paste0(
+            main <- PlotSubTitleItems$new(title = paste0(
                 "Overall Early Stopping",
                 ifelse(futilityStopEnabled, " and Futility Stopping", "")
             ))
@@ -778,7 +776,7 @@ NULL
         .assertIsValidVariedParameterVectorForSimulationResultsPlotting(simulationResults, type)
 
         if (is.na(main)) {
-            main <- PlotSubTitleItems(title = ifelse(survivalEnabled,
+            main <- PlotSubTitleItems$new(title = ifelse(survivalEnabled,
                 "Expected Number of Events", "Expected Number of Subjects"
             ))
             .addPlotSubTitleItems(simulationResults, designMaster, main, type)
@@ -797,7 +795,7 @@ NULL
     } else if (type == 10) { # Study Duration
         .assertIsValidVariedParameterVectorForSimulationResultsPlotting(simulationResults, type)
         if (is.na(main)) {
-            main <- PlotSubTitleItems(title = "Study Duration")
+            main <- PlotSubTitleItems$new(title = "Study Duration")
             .addPlotSubTitleItems(simulationResults, designMaster, main, type)
         }
         xParameterName <- "hazardRatio"
@@ -812,7 +810,7 @@ NULL
     } else if (type == 11) {
         .assertIsValidVariedParameterVectorForSimulationResultsPlotting(simulationResults, type)
         if (is.na(main)) {
-            main <- PlotSubTitleItems(title = "Expected Number of Subjects")
+            main <- PlotSubTitleItems$new(title = "Expected Number of Subjects")
             .addPlotSubTitleItems(simulationResults, designMaster, main, type)
         }
         xParameterName <- "hazardRatio"
@@ -827,7 +825,7 @@ NULL
     } else if (type == 12) { # Analysis Time
         .assertIsValidVariedParameterVectorForSimulationResultsPlotting(simulationResults, type)
         if (is.na(main)) {
-            main <- PlotSubTitleItems(title = "Analysis Time")
+            main <- PlotSubTitleItems$new(title = "Analysis Time")
             .addPlotSubTitleItems(simulationResults, designMaster, main, type)
         }
 
@@ -963,8 +961,7 @@ NULL
 #'
 #' @export
 #'
-plot.SimulationResults <- function(
-        x, y, ..., main = NA_character_,
+plot.SimulationResults <- function(x, y, ..., main = NA_character_,
         xlab = NA_character_, ylab = NA_character_, type = 1L, palette = "Set1",
         theta = seq(-1, 1, 0.01), plotPointsEnabled = NA,
         legendPosition = NA_integer_, showSource = FALSE,
