@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 7644 $
-## |  Last changed: $Date: 2024-02-16 10:36:28 +0100 (Fr, 16 Feb 2024) $
+## |  File version: $Revision: 7941 $
+## |  Last changed: $Date: 2024-05-28 08:44:36 +0200 (Di, 28 Mai 2024) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -56,14 +56,17 @@ NULL
 NULL
 
 #' Parameter Description: Sided
-#' @param sided Is the alternative one-sided (\code{1}) or two-sided (\code{2}), default is \code{1}. Must be a positive integer of length 1.
+#' @param sided Is the alternative one-sided (\code{1}) or two-sided (\code{2}), default is \code{1}. 
+#'    Must be a positive integer of length 1.
 #' @name param_sided
 #' @keywords internal
 NULL
 
 #' Parameter Description: Information Rates
-#' @param informationRates The information rates (that must be fixed prior to the trial),
-#'   default is \code{(1:kMax) / kMax}.
+#' @param informationRates The information rates t_1, ..., t_kMax (that must be fixed prior to the trial),
+#'   default is \code{(1:kMax) / kMax}. For the weighted inverse normal design, the weights are derived
+#'   through w_1 = sqrt(t_1), and w_k = sqrt(t_k - t_(k-1)). For the weighted Fisher's combination test, the 
+#'   weights (scales) are w_k = sqrt((t_k - t_(k-1)) / t_1) (see the documentation).
 #' @name param_informationRates
 #' @keywords internal
 NULL
@@ -283,41 +286,41 @@ NULL
 
 #' Parameter Description: lambda for Counts
 #' @param lambda A numeric value or vector that represents the assumed rate of a homogeneous Poisson process in
-#'   the pooled treatment groups, there is no default. 
+#'   the pooled treatment groups, there is no default.
 #' @name param_lambda_counts
 #' @keywords internal
 NULL
 
 #' Parameter Description: theta for Counts
-#' @param theta A numeric value or vector that represents the assumed mean ratios lambda1/lambda2 of a homogeneous 
-#' Poisson process, there is no default. 
+#' @param theta A numeric value or vector that represents the assumed mean ratios lambda1/lambda2 of a homogeneous
+#' Poisson process, there is no default.
 #' @name param_theta_counts
 #' @keywords internal
 NULL
 
 #' Parameter Description: lambda (1) for Counts
 #' @param lambda1 A numeric value or vector that represents the assumed rate of a homogeneous Poisson process in
-#'   the active treatment group, there is no default. 
+#'   the active treatment group, there is no default.
 #' @name param_lambda1_counts
 #' @keywords internal
 NULL
 
 #' Parameter Description: lambda (2) for Counts
 #' @param lambda2 A numeric value that represents the assumed rate of a homogeneous Poisson process in
-#'   the control group, there is no default. 
+#'   the control group, there is no default.
 #' @name param_lambda2_counts
 #' @keywords internal
 NULL
 
 #' Parameter Description: overdispersion for Counts
-#' @param overdispersion A numeric value that represents the assumed overdispersion of the negative binomial distribution, 
-#' default is \code{0}. 
+#' @param overdispersion A numeric value that represents the assumed overdispersion of the negative binomial distribution,
+#' default is \code{0}.
 #' @name param_overdispersion_counts
 #' @keywords internal
 NULL
 
 #' Parameter Description: fixedExposureTime for Counts
-#' @param fixedExposureTime If specified, the fixed time of exposure per subject for count data, there is no default. 
+#' @param fixedExposureTime If specified, the fixed time of exposure per subject for count data, there is no default.
 #' @name param_fixedExposureTime_counts
 #' @keywords internal
 NULL
@@ -510,7 +513,7 @@ NULL
 
 #' Parameter Description: Minimum Number Of Subjects Per Stage
 #' @param minNumberOfSubjectsPerStage When performing a data driven sample size recalculation,
-#'   the numeric vector \code{minNumberOfSubjectsPerStage} with length kMax determines the
+#'   the numeric vector \code{minNumberOfSubjectsPerStage} with length \code{kMax} determines the
 #'   minimum number of subjects per stage (i.e., not cumulated), the first element
 #'   is not taken into account. For two treatment arms, it is the number of subjects for both treatment arms.
 #'   For multi-arm designs \code{minNumberOfSubjectsPerStage} refers
@@ -521,7 +524,7 @@ NULL
 
 #' Parameter Description: Maximum Number Of Subjects Per Stage
 #' @param maxNumberOfSubjectsPerStage When performing a data driven sample size recalculation,
-#'   the numeric vector \code{maxNumberOfSubjectsPerStage} with length kMax determines the maximum number
+#'   the numeric vector \code{maxNumberOfSubjectsPerStage} with length \code{kMax} determines the maximum number
 #'   of subjects per stage (i.e., not cumulated), the first element is not taken into account.
 #'   For two treatment arms, it is the number of subjects for both treatment arms.
 #'   For multi-arm designs \code{maxNumberOfSubjectsPerStage} refers
@@ -815,8 +818,11 @@ NULL
 
 #' Parameter Description: Select Arms Function
 #' @param selectArmsFunction Optionally, a function can be entered that defines the way of how treatment arms
-#' are selected. This function is allowed to depend on \code{effectVector} with length \code{activeArms}
-#' and \code{stage} (see examples).
+#' are selected. This function is allowed to depend on \code{effectVector} with length \code{activeArms}, 
+#' \code{stage}, \code{"conditionalPower"}, \code{"conditionalCriticalValue"}, \code{"plannedSubjects/plannedEvents"}, 
+#' \code{"allocationRatioPlanned"}, \code{"selectedArms"}, \code{"thetaH1"} (for means and survival), \code{"stDevH1"} (for means), 
+#' \code{"overallEffects"}, and for rates additionally: \code{"piTreatmentsH1"}, \code{"piControlH1"}, \code{"overallRates"}, and 
+#' \code{"overallRatesControl"}. 
 #' @name param_selectArmsFunction
 #' @keywords internal
 NULL
@@ -824,7 +830,10 @@ NULL
 #' Parameter Description: Select Populations Function
 #' @param selectPopulationsFunction Optionally, a function can be entered that defines the way of how populations
 #' are selected. This function is allowed to depend on \code{effectVector} with length \code{populations}
-#' and \code{stage} (see examples).
+#' \code{stage}, \code{"conditionalPower"}, \code{"conditionalCriticalValue"}, \code{"plannedSubjects/plannedEvents"}, 
+#' \code{"allocationRatioPlanned"}, \code{"selectedPopulations"}, \code{"thetaH1"} (for means and survival), \code{"stDevH1"} (for means), 
+#' \code{"overallEffects"}, and for rates additionally: \code{"piTreatmentsH1"}, \code{"piControlH1"}, \code{"overallRates"}, and 
+#' \code{"overallRatesControl"}. 
 #' @name param_selectPopulationsFunction
 #' @keywords internal
 NULL
@@ -905,3 +914,10 @@ NULL
 #' @name param_plotSettings
 #' @keywords internal
 NULL
+
+#' Parameter Description: Planned Calendar Time
+#' @param plannedCalendarTime For simulating count data, the time points where an analysis is planned to be performed.
+#' Should be a vector of length \code{kMax}
+#' @name param_plannedCalendarTime
+#' @keywords internal
+NULL
