@@ -14,8 +14,8 @@
  *
  * Contact us for information about our services: info@rpact.com
  *
- * File version: $Revision: 6617 $
- * Last changed: $Date: 2022-10-18 13:06:16 +0200 (Di, 18 Okt 2022) $
+ * File version: $Revision: 7408 $
+ * Last changed: $Date: 2023-11-09 10:36:19 +0100 (Do, 09 Nov 2023) $
  * Last changed by: $Author: pahlke $
  *
  */
@@ -24,7 +24,6 @@
 
 // [[Rcpp::plugins(cpp11)]]
 
-#include <cmath>
 #include "f_utilities.h"
 
 using namespace Rcpp;
@@ -410,7 +409,7 @@ double getFisherCombinationSizeApproximatelyKmax6Cpp(NumericVector alpha0Vec,
             alpha0Vec, criticalValues, tVec, piValue, getFisherCombinationCaseKmax6Cpp(tVec));
 }
 
-// [[Rcpp::export]]
+// [[Rcpp::export(name = ".getFisherCombinationSizeCpp")]]
 double getFisherCombinationSizeCpp(double kMax, NumericVector alpha0Vec,
 	   NumericVector criticalValues, NumericVector tVec, NumericVector cases) {
     if (criticalValues.length() < 1 || criticalValues.length() > C_KMAX_UPPER_BOUND_FISHER) {
@@ -451,7 +450,7 @@ int getRejectValueForOneTrialCpp(int kMax, NumericVector alpha0,
     return p < criticalValues[stage - 1] ? 1 : -1;
 }
 
-// [[Rcpp::export]]
+// [[Rcpp::export(name = ".getSimulatedAlphaCpp")]]
 double getSimulatedAlphaCpp(int kMax, NumericVector alpha0,
 		NumericVector criticalValues, NumericVector tVec, int iterations) {
 
@@ -482,7 +481,7 @@ double getSimulatedAlphaCpp(int kMax, NumericVector alpha0,
     return var / iterations;
 }
 
-// [[Rcpp::export]]
+// [[Rcpp::export(name = ".getFisherCombinationCases")]]
 NumericVector getFisherCombinationCasesCpp(int kMax, NumericVector tVec) {
     if (kMax == 1) {
         return NumericVector(0);
@@ -512,7 +511,7 @@ double getFisherCombinationSizeCpp(double kMax, NumericVector alpha0Vec,
     return getFisherCombinationSizeCpp(kMax, alpha0Vec, criticalValues, tVec, getFisherCombinationCasesCpp(kMax, tVec));
 }
 
-// [[Rcpp::export]]
+// [[Rcpp::export(name = ".getDesignFisherInner")]]
 List getDesignFisherTryCpp(int kMax, double alpha, double tolerance,
 		NumericVector criticalValues, NumericVector scale,
 		NumericVector alpha0Vec, NumericVector userAlphaSpending, String method) {
@@ -553,12 +552,12 @@ List getDesignFisherTryCpp(int kMax, double alpha, double tolerance,
         while (prec > tolerance && maxIter >= 0) {
             double alpha1 = (cLower + cUpper) * 0.5;
             if (method == C_FISHER_METHOD_EQUAL_ALPHA) {
-                criticalValues = sapply(seq_len(kMax), [=](int k) {
-                    return zeroin([&](double c) {
+                for (int k = 1; k <= kMax; k++) {
+                	criticalValues[k - 1] = zeroin([&](double c) {
                         return getFisherCombinationSizeCpp(
                                 k, rep(1.0, k - 1), rep(c, k), scale, cases) - alpha1;
                     }, tolerance, alpha, tolerance, 1000);
-                });
+                }
             } else if (method == C_FISHER_METHOD_FULL_ALPHA) {
                 for (int k = 0; k < kMax - 1; k++) {
                     double prec2 = 1;
