@@ -14,19 +14,16 @@
 ## |  Contact us for information about our services: info@rpact.com
 ## |  
 ## |  File name: test-f_core_utilities.R
-## |  Creation date: 12 August 2022, 09:09:46
-## |  File version: $Revision: 6514 $
-## |  Last changed: $Date: 2022-08-22 14:31:53 +0200 (Mo, 22 Aug 2022) $
-## |  Last changed by: $Author: pahlke $
+## |  Creation date: 08 November 2023, 09:09:36
+## |  File version: $Revision$
+## |  Last changed: $Date$
+## |  Last changed by: $Author$
 ## |  
 
 test_plan_section("Testing Result Object Print Output")
 
 
 test_that("The output does not contain any issues", {
-        
-    .skipTestIfDisabled()
-        
 	expect_equal(sum(grepl("ISSUES", capture.output(getDesignGroupSequential()$show()))), 0)
 	expect_equal(sum(grepl("ISSUES", capture.output(getDesignInverseNormal(kMax = 4)$show()))), 0)
 	expect_equal(sum(grepl("ISSUES", capture.output(getDesignFisher()$show()))), 0)
@@ -41,8 +38,7 @@ test_plan_section("Testing Core Utility Functions")
 
 
 test_that("'getValidatedInformationRates': 'informationRates' must be generated correctly based on specified 'kMax'", {
-	
-    .skipTestIfDisabled()
+	.skipTestIfDisabled()
 
 	design1 <- getTestDesign(kMax = 1L, designClass = "TrialDesignGroupSequential")
 	expect_equal(.getValidatedInformationRates(design1), 1, tolerance = 1e-08)
@@ -1112,31 +1108,43 @@ test_plan_section("Testing Utilities")
 
 
 test_that("Testing '.moveValue'", {
-        
-    .skipTestIfDisabled()
-        
-    expect_equal(.moveValue(c("A", "B", "C", "D", "E"), "E", "B"), c("A", "B", "E", "C", "D"))
-    expect_equal(.moveValue(c("A", "B", "C", "D", "E"), "E", "A"), c("A", "E", "B", "C", "D"))
-    expect_equal(.moveValue(c("A", "B", "C", "D", "E"), "A", "E"), c("B", "C", "D", "E", "A"))
-    expect_equal(.moveValue(c("A", "B", "C", "D", "E"), "E", "E"), c("A", "B", "C", "D", "E"))
-    expect_equal(.moveValue(c("A", "B", "C", "D", "E"), "A", "A"), c("A", "B", "C", "D", "E"))
-    expect_equal(.moveValue(c("A"), "A", "A"), c("A"))
+	expect_equal(.moveValue(c("A", "B", "C", "D", "E"), "E", "B"), c("A", "B", "E", "C", "D"))
+	expect_equal(.moveValue(c("A", "B", "C", "D", "E"), "E", "A"), c("A", "E", "B", "C", "D"))
+	expect_equal(.moveValue(c("A", "B", "C", "D", "E"), "A", "E"), c("B", "C", "D", "E", "A"))
+	expect_equal(.moveValue(c("A", "B", "C", "D", "E"), "E", "E"), c("A", "B", "C", "D", "E"))
+	expect_equal(.moveValue(c("A", "B", "C", "D", "E"), "A", "A"), c("A", "B", "C", "D", "E"))
+	expect_equal(.moveValue(c("A"), "A", "A"), c("A"))
+
 })
 
 test_that("Testing '.toCapitalized'", {
-        
-    .skipTestIfDisabled()
-        
+
 	expect_equal(.toCapitalized("zip code"), "Zip Code")
 	expect_equal(.toCapitalized("state of the art"), "State of the Art")
 	expect_equal(.toCapitalized("final and count"), "Final and Count")
+	expect_equal(.toCapitalized("Hazard Ratio"), "Hazard Ratio") 
+	expect_equal(.toCapitalized("hazard ratio function"), "Hazard Ratio Function")
+
+})
+
+test_that("Testing '.formatCamelCase'", {
+
+	expect_equal(.formatCamelCase("hazardRatio", title = TRUE), "Hazard Ratio")
+	expect_equal(.formatCamelCase("hazardRatio and informationRates", title = TRUE), "Hazard Ratio and Information Rates")
+	expect_equal(.formatCamelCase("hazardRatio", title = FALSE), "hazard ratio")
+	expect_equal(.formatCamelCase(" hazardRatio ", title = TRUE), " Hazard Ratio ")
+	expect_equal(.formatCamelCase("Hazard", title = TRUE), "Hazard")
+	expect_equal(.formatCamelCase("hazard", title = TRUE), "Hazard")
+	expect_equal(.formatCamelCase("hazard", title = FALSE), "hazard")
+	expect_equal(.formatCamelCase("Hazard", title = FALSE), "hazard")
+	expect_equal(.formatCamelCase("Hazard Ratio", title = TRUE), "Hazard Ratio")
+	expect_equal(.formatCamelCase(" hazard ratio ", title = TRUE), " Hazard Ratio ")
+	expect_equal(.formatCamelCase("HazardRatio", title = FALSE), "hazard ratio")
 
 })
 
 test_that("Testing '.equalsRegexpIgnoreCase'", {
-        
-    .skipTestIfDisabled()
-        
+
 	expect_equal(.equalsRegexpIgnoreCase("stage2", "^stages?$"), FALSE)
 	expect_equal(.equalsRegexpIgnoreCase("stage", "^stages?$"), TRUE)
 	expect_equal(.equalsRegexpIgnoreCase("stages", "^stages?$"), TRUE)
@@ -1151,9 +1159,7 @@ test_that("Testing '.equalsRegexpIgnoreCase'", {
 })
 
 test_that("Testing 'isUndefinedArgument' and 'isValidArgument'", {
-        
-    .skipTestIfDisabled()
-        
+
 	expect_equal(.isUndefinedArgument(NULL), TRUE)
 	expect_equal(.isUndefinedArgument(numeric(0)), TRUE)
 	expect_equal(.isUndefinedArgument(NA), TRUE)
@@ -1181,12 +1187,15 @@ test_that("Testing 'isUndefinedArgument' and 'isValidArgument'", {
 	expect_error(.isDefinedArgument(notExistingTestVariable, argumentExistsValidationEnabled = FALSE))
 	expect_error(.isDefinedArgument(notExistingTestVariable))
 
+	# skip_if_translated()
+	# expect_error(.isDefinedArgument(notExistingTestVariable),
+	# 	paste0("Missing argument: the object 'notExistingTestVariable' has not been defined anywhere. ",
+	# 	"Please define it first, e.g., run 'notExistingTestVariable <- 1'"), fixed = TRUE)
+
 })
 
 test_that("Result of 'setSeed(seed)' is working for different arguments, incl. NULL and NA", {
-        
-    .skipTestIfDisabled()
-        
+
 	# @refFS[Sec.]{fs:sec:reproducibilityOfSimulationResults}
 	expect_false(is.null(.setSeed()))
 	expect_false(is.na(.setSeed()))
@@ -1209,9 +1218,7 @@ test_that("Result of 'setSeed(seed)' is working for different arguments, incl. N
 })
 
 test_that("Testing '.getInputForZeroOutputInsideTolerance''", {
-        
-    .skipTestIfDisabled()
-        
+
 	input <- 99
 	tolerance <- 1e-05
 	epsilon <- 1e-08
@@ -1223,9 +1230,7 @@ test_that("Testing '.getInputForZeroOutputInsideTolerance''", {
 })
 
 test_that("Testing '.arrayToString'", {
-        
-    .skipTestIfDisabled()
-        
+
 	expect_equal(.arrayToString(NA, vectorLookAndFeelEnabled = TRUE), "NA")
 	expect_equal(.arrayToString(NULL, vectorLookAndFeelEnabled = TRUE), "NULL")
 	expect_equal(.arrayToString(c(1, 2, 3), vectorLookAndFeelEnabled = TRUE), "c(1, 2, 3)")
@@ -1237,9 +1242,7 @@ test_that("Testing '.arrayToString'", {
 })
 
 test_that("Testing '.getQNorm'", {
-        
-    .skipTestIfDisabled()
-        
+
 	expect_equal(sign(.getQNorm(1)), sign(qnorm(1)))
 	expect_equal(.getQNorm(1 - 1e-12), qnorm(1 - 1e-12))
 	expect_equal(sign(.getQNorm(0)), sign(qnorm(0)))
@@ -1248,9 +1251,7 @@ test_that("Testing '.getQNorm'", {
 })
 
 test_that("Testing '.getOneMinusQNorm'", {
-        
-    .skipTestIfDisabled()
-        
+
 	expect_equal(sign(.getOneMinusQNorm(1)), sign(1 - qnorm(1)))
 	expect_equal(.getOneMinusQNorm(1 - 1e-12), -qnorm(1 - 1e-12))
 	expect_equal(sign(.getOneMinusQNorm(0)), sign(1 - qnorm(0)))
@@ -1259,9 +1260,7 @@ test_that("Testing '.getOneMinusQNorm'", {
 })
 
 test_that("Testing '.getInputProducingZeroOutput'", {
-        
-    .skipTestIfDisabled()
-        
+
 	tolerance <- 1e-05
 	epsilon <- 1e-08
 
@@ -1360,8 +1359,8 @@ test_that("Testing '.getOneDimensionalRoot'", {
 	result1 <- getRepeatedConfidenceIntervals(design1, dataExample1, stage = 3)
 
 	## Comparison of the results of matrixarray object 'result1' with expected results
-	expect_equal(result1[1, ], c(0.54923831, 0.77922365, 1.0261298), tolerance = 1e-07)
-	expect_equal(result1[2, ], c(3.7041718, 2.7014099, 2.5669073), tolerance = 1e-07)
+	expect_equal(result1[1, ], c(0.54923831, 0.77922365, 1.0261298), tolerance = 1e-07, label = paste0("c(", paste0(result1[1, ], collapse = ", "), ")"))
+	expect_equal(result1[2, ], c(3.7041718, 2.7014099, 2.5669073), tolerance = 1e-07, label = paste0("c(", paste0(result1[2, ], collapse = ", "), ")"))
 
 	design2 <- getDesignGroupSequential(
 	    kMax = 3, alpha = 0.025, informationRates = c(0.4, 0.7, 1),
@@ -1379,8 +1378,8 @@ test_that("Testing '.getOneDimensionalRoot'", {
 	)
 
 	## Comparison of the results of matrixarray object 'result2' with expected results
-	expect_equal(result2[1, ], c(-0.17491833, -0.048575314, 0.018957987), tolerance = 1e-07)
-	expect_equal(result2[2, ], c(0.41834377, 0.2916876, 0.31353674), tolerance = 1e-07)
+	expect_equal(result2[1, ], c(-0.17491833, -0.048575314, 0.018957987), tolerance = 1e-07, label = paste0("c(", paste0(result2[1, ], collapse = ", "), ")"))
+	expect_equal(result2[2, ], c(0.41834377, 0.2916876, 0.31353674), tolerance = 1e-07, label = paste0("c(", paste0(result2[2, ], collapse = ", "), ")"))
 
 	design3 <- getDesignInverseNormal(
 	    kMax = 2, alpha = 0.025, informationRates = c(0.5, 1),
@@ -1395,8 +1394,8 @@ test_that("Testing '.getOneDimensionalRoot'", {
 	result3 <- getRepeatedConfidenceIntervals(design3, dataExample3)
 
 	## Comparison of the results of matrixarray object 'result3' with expected results
-	expect_equal(result3[1, ], c(-0.26729325, -0.071746001), tolerance = 1e-07)
-	expect_equal(result3[2, ], c(0.26729325, 0.071746001), tolerance = 1e-07)
+	expect_equal(result3[1, ], c(-0.26729325, -0.071746001), tolerance = 1e-07, label = paste0("c(", paste0(result3[1, ], collapse = ", "), ")"))
+	expect_equal(result3[2, ], c(0.26729325, 0.071746001), tolerance = 1e-07, label = paste0("c(", paste0(result3[2, ], collapse = ", "), ")"))
 
 	design4 <- getDesignInverseNormal(
 	    kMax = 2, alpha = 0.025, informationRates = c(0.5, 1),
@@ -1411,7 +1410,7 @@ test_that("Testing '.getOneDimensionalRoot'", {
 	result4 <- getRepeatedConfidenceIntervals(design4, dataExample4)
 
 	## Comparison of the results of matrixarray object 'result4' with expected results
-	expect_equal(result4[1, ], c(-0.23589449, -0.043528426), tolerance = 1e-07)
-	expect_equal(result4[2, ], c(0.23589449, 0.088472144), tolerance = 1e-07)
+	expect_equal(result4[1, ], c(-0.23589449, -0.043528426), tolerance = 1e-07, label = paste0("c(", paste0(result4[1, ], collapse = ", "), ")"))
+	expect_equal(result4[2, ], c(0.23589449, 0.088472144), tolerance = 1e-07, label = paste0("c(", paste0(result4[2, ], collapse = ", "), ")"))
 })
 
